# TVDB RSS

A small Python library to generate an RSS of new shows (that I want to watch)

# Documentation

I recommend just looking at the source code for how things work. If there is community interest, I can doc-up the code better.

# Install
```
pip install tvdb_rss
```

# License

MIT License